improved indentation and whitespace for markdown code blocks
All code blocks in markdown have been intended by at least 4 spaces. We add `--tab-stop=8` to all `pandoc(1)` executions in order to set a better tab stop indentation, especially for tab intended code blocks. Changed `bin/pandoc-wrapper.sh` VERSION from "1.5.3 2024-03-26" to "1.6 2024-03-31". Fixed `1991/brnstnd/sorta.README.md` so that the sorta code is code blocks. Removed unneeded paragraph group in copyright in `inc/footer.default.html`. Fixed excess whitespace after list Author on entry `index.html` page. Changed `bin/output-index-author.sh` VERSION from "1.5.2 2024-03-26" to "1.6 2024-03-31". Performed `make www` to perform the above and test under macOS. TODO: Fix the problem of the initial line of code being extra intended. TODO: Fix excess whitespace around code that is inline.
This commit is contained in:
1 parent
b84c27ce02
commit
a996f8d2b8
734 files changed
+16723
-16963
No files matched your search
+5
-5
@@ -1,14 +1,14 @@
|
||||
## To build:
|
||||
|
||||
```sh
|
||||
make all
|
||||
make all
|
||||
```
|
||||
|
||||
|
||||
## To use:
|
||||
|
||||
```sh
|
||||
./rcm < file.gz
|
||||
./rcm < file.gz
|
||||
```
|
||||
|
||||
where `file.gz` is some gzipped file.
|
||||
@@ -19,7 +19,7 @@ where `file.gz` is some gzipped file.
|
||||
For more information try:
|
||||
|
||||
```sh
|
||||
./try.sh
|
||||
./try.sh
|
||||
```
|
||||
|
||||
|
||||
@@ -28,7 +28,7 @@ For more information try:
|
||||
For a good no-op try:
|
||||
|
||||
```sh
|
||||
gzip -c < rcm.c | ./rcm
|
||||
gzip -c < rcm.c | ./rcm
|
||||
```
|
||||
|
||||
NOTE: this is done in the [try.sh](try.sh) script as well, along with some other
|
||||
@@ -71,7 +71,7 @@ from the GNU gzip source tree is 31,613 characters in length and uncompresses
|
||||
the emacs distribution file in slightly under 25 seconds. Thus:
|
||||
|
||||
```
|
||||
3100 / 130 = 23.85 -vs- 31613 / 25 = 1264.52
|
||||
3100 / 130 = 23.85 -vs- 31613 / 25 = 1264.52
|
||||
```
|
||||
|
||||
which represents a better than 530% improvement in the ratio of
|
||||
|
||||
Reference in new issue
Block a user